summaryrefslogtreecommitdiff
path: root/gtk2_ardour/main_clock.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/main_clock.h')
-rw-r--r--gtk2_ardour/main_clock.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/gtk2_ardour/main_clock.h b/gtk2_ardour/main_clock.h
index 959a3f9440..f5f9096b39 100644
--- a/gtk2_ardour/main_clock.h
+++ b/gtk2_ardour/main_clock.h
@@ -19,15 +19,24 @@
#include "audio_clock.h"
/** A simple subclass of AudioClock that adds the `display delta to edit cursor' option to its context menu */
class MainClock : public AudioClock
{
public:
- MainClock (const std::string &, bool, const std::string &, bool, bool, bool primary, bool duration = false, bool with_info = false);
+ MainClock (const std::string& clock_name, bool is_transient, const std::string& widget_name,
+ bool editable, bool follows_playhead, bool primary, bool duration = false, bool with_info = false);
private:
+ // Editor *_editor;
+
void build_ops_menu ();
void display_delta_to_edit_cursor ();
+ void edit_current_tempo ();
+ void edit_current_meter ();
+ void insert_new_tempo ();
+ void insert_new_meter ();
bool _primary;
};
@@ -19,15 +19,24 @@
#include "audio_clock.h"
-/** A simple subclass of AudioClock that adds the `display delta to edit cursor' option to its context menu */
+/** A simple subclass of AudioClock that adds a few things to its context menu:
+ * `display delta to edit cursor' and edit/change tempo/meter
+ */
class MainClock : public AudioClock
{